#include "sinwave.h"
#include "ui_sinwave.h"
#include "multithread.h"
#include <QtGui>
#include <QPalette>
#include <cmath>
#include <QPainterPath>
#include <QPainter>
#include <QThread>
#include <QDebug>


static int i=0;
static int XStartpoint=0;
static int YStartpoint=0;
static int jCount=5;

Sinwave::Sinwave(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::Sinwave)
{
    ui->setupUi(this);
    thread = new QThread();
    multithread = new MultiThread();

    multithread->moveToThread(thread);
    connect(multithread, SIGNAL(valueChanged(QString)), ui->labelCount, SLOT(setText(QString)));
    connect(multithread, SIGNAL(multithreadRequested()), thread, SLOT(start()));
    connect(thread, SIGNAL(started()), multithread, SLOT(doMultiThraed()));
    connect(multithread, SIGNAL(finished()), thread, SLOT(quit()), Qt::DirectConnection);
    // receive the emited signal
    connect(multithread, SIGNAL(value()),SLOT(display()));

}

Sinwave::~Sinwave()
{
    multithread->abort();
    thread->wait();
    qDebug()<<this->QObject::thread()->currentThreadId();
    delete thread;
    delete multithread;
    delete ui;
}

void Sinwave::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void Sinwave::paintEvent(QPaintEvent *pEvent)
{

    QWidget::paintEvent(pEvent);
    QPainter painter(this);
    painter.setRenderHint(QPainter::Antialiasing);
    painter.setPen(Qt::red);
    painter.drawLine(100,200,100,600);
    painter.drawLine(100,400,750,400);

    painter.drawText(630,430,"-> Time X axis");
    painter.drawText(70,250,"^");
    painter.drawText(73,252,"|");
    painter.drawText(80,255,"A");

    //arrows

    painter.drawLine(750,400,740,390);
    painter.drawLine(750,400,740,410);

    painter.drawLine(100,200,110,210);
    painter.drawLine(100,200,90,210);



    QPainterPath path1;
    path1.moveTo(XStartpoint,YStartpoint);
    qreal tempAmp;

    for(int SS=0;SS<sinCount;SS++)
    {
        tempAmp=amplitude;
        for(int a=1;a<amplitude;a++)
        {
            X1+=Ttime/tempAmp;
            tempAmp--;
            Y1-=1;

            path1.lineTo(X1,Y1);
            path1.moveTo(X1,Y1);
        }
        tempAmp=1;
        for(int g=amplitude;g>0;g--)
        {
            X1+=Ttime/tempAmp;
            tempAmp++;
            Y1+=1;

            path1.lineTo(X1,Y1);
            path1.moveTo(X1,Y1);
        }
// second

        tempAmp=amplitude;
        for(int a=1;a<amplitude;a++)
        {
           X1+=Ttime/tempAmp;
           tempAmp--;
           Y1+=1;

           path1.lineTo(X1,Y1);
           path1.moveTo(X1,Y1);
        }
        tempAmp=1;
        for(int g=amplitude;g>0;g--)
        {
            X1+=Ttime/tempAmp;
            tempAmp++;
            Y1-=1;

            path1.lineTo(X1,Y1);
            path1.moveTo(X1,Y1);
        }
    }
    painter.drawPath(path1);
}




void Sinwave::on_actionSTART_activated()
{

}

void Sinwave::on_actionStart_activated()
{
    // code to start multithread
    multithread->abort();
    thread->wait();
    multithread->requestThread();
}


void Sinwave::on_actionPause_activated()
{
    // Pause mulithread
    multithread->abort();
    thread->wait();
}

void Sinwave::display()
{

    QString amp=ui->textEditAmplitude->toPlainText();
    QString tym=ui->textEditTime->toPlainText();
    amplitude=amp.toInt();
    Ttime=tym.toInt();
    X1=100.0;
    Y1=400.0;
    XStartpoint=100;
    YStartpoint=400;
    QString lbl=ui->labelCount->text();
    lbl1=lbl.toInt();
    if(lbl1==1)
    {

        sinCount=1;
        repaint();
    }
    else if(lbl1==2)
    {
        sinCount=2;
        repaint();
    }
    if(lbl1==3)
    {
        sinCount=3;
        repaint();
    }
    if(lbl1==4)
    {
        sinCount=4;
        repaint();
    }
    if(lbl1==5)
    {
        sinCount=5;
        repaint();
    }

}

void Sinwave::on_pushButtonStart_clicked()
{
    // copy code to generate sin wave
       amplitude=0.0;
       Ttime=0.0;
       X1=100.0;
       Y1=400.0;
       QString amp=ui->textEditAmplitude->toPlainText();
       QString tym=ui->textEditTime->toPlainText();
       amplitude=amp.toInt();
       Ttime=tym.toInt();
       XStartpoint=100;
       YStartpoint=400;
       sinCount=5;
       repaint();
}
